Mixed-Up Code Exercises
-----------------------

Answer the following **Mixed-Up Code** or **Activecode** questions to
assess what you have learned in this chapter.

.. selectquestion:: mucp_9_1_sq
   :fromid: mucp_9_1, mucp_9_1_ac_q
   :toggle:

.. selectquestion:: mucp_9_2_sq
   :fromid: mucp_9_2, mucp_9_2_ac_q
   :toggle:

.. selectquestion:: mucp_9_3_sq
   :fromid: mucp_9_3, mucp_9_3_ac_q
   :toggle:

.. selectquestion:: mucp_9_4_sq
   :fromid: mucp_9_4, mucp_9_4_ac_q
   :toggle:

.. selectquestion:: mucp_9_5_sq
   :fromid: mucp_9_5, mucp_9_5_ac_q
   :toggle:

.. selectquestion:: mucp_9_6_sq
   :fromid: mucp_9_6, mucp_9_6_ac_q
   :toggle:

.. selectquestion:: mucp_9_7_sq
   :fromid: mucp_9_7, mucp_9_7_ac_q
   :toggle:

.. selectquestion:: mucp_9_8_sq
   :fromid: mucp_9_8, mucp_9_8_ac_q
   :toggle:

.. selectquestion:: mucp_9_9_sq
   :fromid: mucp_9_9, mucp_9_9_ac_q
   :toggle:

.. selectquestion:: mucp_9_10_sq
   :fromid: mucp_9_10, mucp_9_10_ac_q
   :toggle:
